==> rpg_icon_generator-0.1.1.tar.gz: rpg_icon_generator-0.1.1/test/test_blade_generator.py <==
import unittest
from rpg_icon_generator import Blade_Generator
from rpg_icon_generator.utils.constants import RARITY_RANGE
from datetime import datetime
import os.path

class Test_blade_generation(unittest.TestCase):

    def test_generation(self):
        generator = Blade_Generator()
        seed = datetime.now()
        generator.generate(seed=seed, dimension=64, render_scale=2, output_directory='./test/out/', complexity=50)
        self.assertTrue(os.path.isfile("./test/out/{}.png".format(seed)))

    def test_generation_chain(self):
        generator = Blade_Generator()
        for i in range(10):
            seed = str(datetime.now()) + str(i)
            generator.generate(seed=seed, dimension=64, render_scale=2, output_directory='./test/out/', complexity=50)
            self.assertTrue(os.path.isfile("./test/out/{}.png".format(seed)))

    def test_generation_all_complexity(self):
        generator = Blade_Generator()
        for name, c in RARITY_RANGE.items():
            date = str(datetime.now())
            seed = "{}_min_{}".format(date, name)
            generator.generate(seed=seed, dimension=64, render_scale=2, output_directory='./test/out/', complexity=c[0])
            self.assertTrue(os.path.isfile("./test/out/{}.png".format(seed)))
            seed = "{}_max_{}".format(date, name)
            generator.generate(seed=seed, dimension=64, render_scale=2,output_directory='./test/out/', complexity=c[1])
            self.assertTrue(os.path.isfile("./test/out/{}.png".format(seed)))
        

if __name__ == '__main__':
    unittest.main()

==> rpg_icon_generator-0.3.0.tar.gz: rpg_icon_generator-0.3.0/test/test_blade_generator.py <==
import unittest
from rpg_icon_generator import Blade_Generator
from rpg_icon_generator.utils.constants import RARITY_RANGE
from datetime import datetime
import os.path
import random

class Test_blade_generation(unittest.TestCase):

    def test_generation(self):
        generator = Blade_Generator()
        seed = datetime.now()
        generator.generate(seed=seed, dimension=64, render_scale=2, output_directory='./test/out/', complexity=50)
        self.assertTrue(os.path.isfile("./test/out/{}.png".format(seed)))

    def test_generation_chain(self):
        generator = Blade_Generator()
        for i in range(10):
            seed = str(datetime.now()) + str(i)
            generator.generate(seed=seed, dimension=64, render_scale=2, output_directory='./test/out/', complexity=random.randrange(0, 101))
            self.assertTrue(os.path.isfile("./test/out/{}.png".format(seed)))

    def test_generation_all_complexity(self):
        generator = Blade_Generator()
        for name, c in RARITY_RANGE.items():
            date = str(datetime.now())
            seed = "{}_min_{}".format(date, name)
            generator.generate(seed=seed, dimension=64, render_scale=2, output_directory='./test/out/', complexity=c[0])
            self.assertTrue(os.path.isfile("./test/out/{}.png".format(seed)))
            seed = "{}_max_{}".format(date, name)
            generator.generate(seed=seed, dimension=64, render_scale=2,output_directory='./test/out/', complexity=c[1])
            self.assertTrue(os.path.isfile("./test/out/{}.png".format(seed)))
        

if __name__ == '__main__':
    unittest.main()
